@@ -4,54 +4,31 @@ Created on Thu Jul 05 09:37:38 2018
 
 @author: a002028
 """
-""" Sea-Bird reader
-"""
-import re
-
 from ctdpy.core import utils
 from ctdpy.core.readers.seabird import SeaBird
-from ctdpy.core.readers.metadata import XLSXmeta
+from ctdpy.core.readers.metadata import XLSXmeta, TXTmeta
 
 
 class SeaBirdSMHI(SeaBird):
-    """
-    """
+    """Reader for seabird data according to SMHI processing routines."""
+
     def __init__(self, settings):
+        """Initialize."""
         super().__init__(settings)
 
-    @staticmethod
-    def _get_serno(value):
-        """
-        IN SMHI Seabird CTD-files there usually are specified information about "LIMS Job", which is the SMHI-internal
-        key number YEAR-SHIP-SERNO. This method picks out the SERNO number.
-        :param value:
-        :return:
-        """
-        lims_job_list = re.findall(r"[0-9]{4}", value)
-        if len(lims_job_list):
-            serno = lims_job_list[-1]
-        else:
-            serno = ''
-
-        return serno
-
     def _extract_filename_information(self, filename):
-        """
-
-        :param filename:
-        :return:
-        """
-        # pattern = '{sensor_id:5s}_{sensor_serial_number:4s}_{visit_date:%Y%m%d}_{sample_time:%H%M}_{cntry:2d}_{shipc:2d}_{serno:4d}.cnv'
+        """Get filename information."""
         dictionary = {}
         info_list = filename.split('_')
         dictionary['INSTRUMENT_SERIE'] = info_list[1]
         return dictionary
 
     def _convert_formats(self, meta_dict, filename=None):
-        """
-        :param meta_dict:
-        :return:
-        """
+        """Set and/or convert formats of metadata."""
+        timestamp = self._get_datetime(meta_dict['SDATE'])
+        meta_dict['SDATE'] = utils.get_format_from_datetime_obj(timestamp, '%Y-%m-%d')
+        meta_dict['STIME'] = utils.get_format_from_datetime_obj(timestamp, '%H:%M')
+
         meta_dict['SERNO'] = self._get_serno(meta_dict['SERNO'])
         meta_dict.setdefault('PROJ', 'BAS')
         meta_dict.setdefault('ORDERER', 'HAV, SMHI')
@@ -64,23 +41,18 @@ class SeaBirdSMHI(SeaBird):
                 meta_dict[item] = value
 
     def get_metadata(self, serie, map_keys=True, filename=None):
-        """
-        :param serie: pd.Series
-        :param map_keys: False or True
-        :return: Dictionary with metadata
-        """
+        """Return dictionary with metadata."""
         meta_dict = {}
         for ident, sep in zip(['identifier_metadata', 'identifier_metadata_2'],
                               ['separator_metadata', 'separator_metadata_2']):
-            data = self.get_meta_dict(serie, 
-                                      identifier=self.settings.datasets['cnv'].get(ident), 
+            data = self.get_meta_dict(serie,
+                                      identifier=self.settings.datasets['cnv'].get(ident),
                                       separator=self.settings.datasets['cnv'].get(sep),
                                       keys=self.settings.datasets['cnv'].get('keys_metadata'))
-            
+
             meta_dict = utils.recursive_dict_update(meta_dict, data)
-            
+
         if map_keys:
-            # meta_dict = {self.settings.pmap.get(key): meta_dict[key] for key in meta_dict}
             new_dict = {}
             for key in meta_dict:
                 if meta_dict[key]:
@@ -91,45 +63,23 @@ class SeaBirdSMHI(SeaBird):
         return meta_dict
 
     def _setup_dataframe(self, serie, metadata=None):
-        """
-        :param serie: pd.Series
-        :return: pd.DataFrame
-        """
-        # print(self.df_handler.__dict__)
+        """Convert pandas Serie into pandas DataFrame."""
         header = self.get_data_header(serie, dataset='cnv')
         df = self.get_data_in_frame(serie, header, dataset='cnv')
         df = self.df_handler.map_column_names_of_dataframe(df)
-        
+
         return df
 
 
 class MVPSMHI(SeaBird):
-    """
-    """
+    """Reader for MVP-data according to SMHI processing routines."""
+
     def __init__(self, settings):
+        """Initialize."""
         super().__init__(settings)
-
-    @staticmethod
-    def _get_serno(value):
-        """
-        IN SMHI Seabird CTD-files there usually are specified information about "LIMS Job", which is the SMHI-internal
-        key number YEAR-SHIP-SERNO. This method picks out the SERNO number.
-        :param value:
-        :return:
-        """
-        lims_job_list = re.findall(r"[0-9]{4}", value)
-        if len(lims_job_list):
-            serno = lims_job_list[-1]
-        else:
-            serno = ''
-
-        return serno
 
     def _convert_formats(self, meta_dict):
-        """
-        :param meta_dict:
-        :return:
-        """
+        """Set and/or convert formats of metadata."""
         # meta_dict['SERNO'] = self._get_serno(meta_dict['SERNO'])
         meta_dict.setdefault('PROJ', 'BAS')
         meta_dict.setdefault('ORDERER', 'SMHI')
@@ -138,11 +88,7 @@ class MVPSMHI(SeaBird):
         meta_dict.setdefault('POSYS', 'GPS')
 
     def get_metadata(self, serie, map_keys=True, filename=None):
-        """
-        :param serie: pd.Series
-        :param map_keys: False or True
-        :return: Dictionary with metadata
-        """
+        """Return dictionary with metadata."""
         meta_dict = {}
         for ident, sep in zip(['identifier_metadata', 'identifier_metadata_2'],
                               ['separator_metadata', 'separator_metadata_2']):
@@ -154,7 +100,6 @@ class MVPSMHI(SeaBird):
             meta_dict = utils.recursive_dict_update(meta_dict, data)
 
         if map_keys:
-            # meta_dict = {self.settings.pmap.get(key): meta_dict[key] for key in meta_dict}
             new_dict = {}
             for key in meta_dict:
                 if meta_dict[key]:
@@ -165,11 +110,7 @@ class MVPSMHI(SeaBird):
         return meta_dict
 
     def _setup_dataframe(self, serie, metadata=None):
-        """
-        :param serie: pd.Series
-        :return: pd.DataFrame
-        """
-        # print(self.df_handler.__dict__)
+        """Convert pandas Serie into pandas DataFrame."""
         header = self.get_data_header(serie, dataset='cnv')
         df = self.get_data_in_frame(serie, header, dataset='cnv')
         df = self.df_handler.map_column_names_of_dataframe(df)
@@ -178,28 +119,34 @@ class MVPSMHI(SeaBird):
 
 
 class MetadataSMHI(XLSXmeta):
-    """
-    """
+    """Reader for metadata according to SMHI datahost template."""
+
     def __init__(self, settings):
+        """Initialize."""
         super().__init__(settings)
         self.data = {}
         self.file_specs = self.settings.readers['smhi']['datasets']['xlsx']
 
 
-class MasterSMHI(SeaBird):
-    """
-    """
+class MetadataTxtSMHI(TXTmeta):
+    """Reader for text file oriented metadata according to SMHI datahost template."""
 
     def __init__(self, settings):
+        """Initialize."""
+        super().__init__(settings)
+        self.data = {}
+        self.file_specs = self.settings.readers['smhi']['datasets']['txt']
+
+
+class MasterSMHI(SeaBird):
+    """Reader for seabird data according to the new SMHI processing routines."""
+
+    def __init__(self, settings):
+        """Initialize."""
         super().__init__(settings)
 
     def _extract_filename_information(self, filename):
-        """
-
-        :param filename:
-        :return:
-        """
-        # pattern = '{sensor_id:5s}_{sensor_serial_number:4s}_{visit_date:%Y%m%d}_{sample_time:%H%M}_{cntry:2d}_{shipc:2d}_{serno:4d}.cnv'
+        """Get filename information."""
         dictionary = {}
         info_list = filename.split('_')
         dictionary['INSTRUMENT_SERIE'] = info_list[1]
@@ -207,10 +154,11 @@ class MasterSMHI(SeaBird):
         return dictionary
 
     def _convert_formats(self, meta_dict, filename=None):
-        """
-        :param meta_dict:
-        :return:
-        """
+        """Set and/or convert formats of metadata."""
+        timestamp = self._get_datetime(meta_dict['SDATE'])
+        meta_dict['SDATE'] = utils.get_format_from_datetime_obj(timestamp, '%Y-%m-%d')
+        meta_dict['STIME'] = utils.get_format_from_datetime_obj(timestamp, '%H:%M')
+
         # meta_dict['SERNO'] = self._get_serno(meta_dict['SERNO'])
         meta_dict.setdefault('PROJ', 'BAS')
         meta_dict.setdefault('ORDERER', 'HAV, SMHI')
@@ -223,11 +171,7 @@ class MasterSMHI(SeaBird):
                 meta_dict[item] = value
 
     def get_metadata(self, serie, map_keys=True, filename=None):
-        """
-        :param serie: pd.Series
-        :param map_keys: False or True
-        :return: Dictionary with metadata
-        """
+        """Return dictionary with metadata."""
         meta_dict = {}
         for ident, sep in zip(['identifier_metadata', 'identifier_metadata_2'],
                               ['separator_metadata', 'separator_metadata_2']):
@@ -239,7 +183,6 @@ class MasterSMHI(SeaBird):
             meta_dict = utils.recursive_dict_update(meta_dict, data)
 
         if map_keys:
-            # meta_dict = {self.settings.pmap.get(key): meta_dict[key] for key in meta_dict}
             new_dict = {}
             for key in meta_dict:
                 if meta_dict[key]:
@@ -250,11 +193,7 @@ class MasterSMHI(SeaBird):
         return meta_dict
 
     def _setup_dataframe(self, serie, metadata):
-        """
-        :param serie: pd.Series
-        :return: pd.DataFrame
-        """
-        # print(self.df_handler.__dict__)
+        """Convert pandas Serie into pandas DataFrame."""
         header = self.get_data_header(serie, dataset='cnv')
         df = self.get_data_in_frame(serie, header, dataset='cnv')
         df = self.df_handler.map_column_names_of_dataframe(df)
